@@ -10,8 +10,8 @@ class OSMRailwayElement(ABC):
     def __init__(self, n: overpy.Node):
         self.n = n
         self.attributes = n.attributes
-        self.lat = n.lat
-        self.lon = n.lon
+        self.lat = float(n.lat)
+        self.lon = float(n.lon)
         self.id = n.id
 
         if hasattr(n, "ways"):
